@@ -5,7 +5,7 @@ import ast
 import platform
 import sys
 import traceback
-from typing import Sequence
+from collections.abc import Sequence
 
 
 def main(argv: Sequence[str] | None = None) -> int:
