@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import argparse
-from typing import Sequence
+from collections.abc import Sequence
 
 BLACKLIST = [
     b'BEGIN RSA PRIVATE KEY',
